# gemspa-spt
 
This package provides the ParticleTracks class, which can read track files (Mosaic, Trackmate, GEMspa, or trackpy 
formats) and perform analysis for single particle tracking data.


Analysis functions include: msd/ensemble-msd, (effective) diffusion coefficient, anomalous exponent, step size, 
radius of gyration.